.. module:: jnrbase
   :synopsis: Common utility functionality

API documentation
=================

|modref| comprises of the following modules, some of which may require external
dependencies to function.

.. toctree::
   :maxdepth: 2

   attrdict
   cmdline
   colourise
   config
   context
   debug
   entry
   git
   httplib2_certs
   human_time
   i18n
   iso_8601
   json_datetime
   pager
   pip_support
   template
   timer
   xdg_basedir
